PyASGE
=====================
A simple framework for creating 2D games.

PyASGE is a series of Python bindings designed to work with the modern C++
AwesomeSauce GameEngine. ASGE is a simplistic game framework that is designed
to allow rapid prototyping of 2D games. It's main concerns are pedagogic in
nature, but it does offer enough features to allow creation of responsive and
reasonably performant games.

Its design is opinionated and this is a conscious decision to allow learning
of games programming without the concerns low-level APIs such as Window
management. It **specifically** aims to reduce the complexity of larger game
engine and frameworks.

**ASGE and thus PyASGE are focused on using modern language features. Legacy
compiler or OS support is not a primary requirement, though where possible
the API does attempt to maintain backwards compatibility.**
